@@ -14,7 +14,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import sqlparse
 import looker_sdk
 from looker_sdk import models
 import json
@@ -30,6 +29,17 @@ from lmanage.utils import parsing_sql
 from lmanage.utils import create_df
 import coloredlogs
 import logging
+import sys
+
+logger = logging.getLogger(__name__)
+logger.setLevel(logging.DEBUG)
+logging.getLogger().addHandler(logging.StreamHandler(sys.stdout))
+fh = logging.FileHandler('map_view.log')
+fh.setLevel(logging.DEBUG)
+formatter = logging.Formatter(
+    '%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+fh.setFormatter(formatter)
+logger.addHandler(fh)
 
 logger = logging.getLogger(__name__)
 
@@ -81,24 +91,33 @@ def fetch_view_files(proj):
         A dict with key: being the base view and values: list of all the used views in the explore object.
         For example:
          defaultdict(<class 'list'>, {'order_items': ['order_items', 'order_facts', 'inventory_items', 'users', 'user_order_facts', 'products', 'repeat_purchase_facts', 'distribution_centers', 'test_ndt'], 'events':['events', 'sessions', 'session_landing_page', 'session_bounce_page', 'product_viewed', 'users', 'user_order_facts']})    """
-    file = find_model_files(proj)
+
     true_view_names = defaultdict(list)
-    for explore in file.explores:
-        if 'view_name' not in explore and 'from' not in explore:
-            true_view_names[explore.name].append(explore.name)
-        if 'view_name' in explore:
-            true_view_names[explore['name']].append(
-                explore['view_name'].value)
-        if 'from' in explore:
-            true_view_names[explore['name']].append(explore['from'].value)
-        if 'join' in explore:
-            for join in explore['join']:
-                true_view_names[explore['name']].append(join['name'])
-                if 'view_name' in join.__dict__.keys():
+
+    for file in proj.files():
+        path = file.path
+        myFile = proj.file(path)
+        if myFile.type == 'model':
+            my_model = file
+
+            for explore in my_model.explores:
+                if 'view_name' not in explore and 'from' not in explore:
+                    true_view_names[explore.name].append(explore.name)
+                if 'view_name' in explore:
                     true_view_names[explore['name']].append(
-                        join['view_name'].value)
-                if 'from' in join.__dict__.keys():
-                    true_view_names[explore['name']].append(join['from'].value)
+                        explore['view_name'].value)
+                if 'from' in explore:
+                    true_view_names[explore['name']].append(
+                        explore['from'].value)
+                if 'join' in explore:
+                    for join in explore['join']:
+                        true_view_names[explore['name']].append(join['name'])
+                        if 'view_name' in join.__dict__.keys():
+                            true_view_names[explore['name']].append(
+                                join['view_name'].value)
+                        if 'from' in join.__dict__.keys():
+                            true_view_names[explore['name']].append(
+                                join['from'].value)
     return true_view_names
 
 
@@ -310,6 +329,7 @@ def all_views(myresults, proj):
 
 def match_views_per_query(myresults, proj):
     result = []
+    paths = []
     used_joins = myresults['used_joins']
     for join in used_joins:
         if not bool(test_period_appearence(join)):
@@ -321,8 +341,10 @@ def match_views_per_query(myresults, proj):
             for view in myFile.views:
                 if view.sql_table_name.value in used_joins:
                     result.append(view.name)
+                    paths.append(path)
 
     myresults['used_view_names'] = result
+    myresults['sql_table_paths_'] = paths
     return myresults
 
 
@@ -342,7 +364,6 @@ def match_view_to_dash(content_results, explore_results, sql_table_name, proj):
     tables_in_explore = []
 
     sql_table_name_ = get_sql_table_name_list(sql_table_name, key=False)
-    sql_table_paths_ = get_sql_table_name_list(sql_table_name, key=True)
 
     for content in content_results:
         result = defaultdict(list)
@@ -352,7 +373,6 @@ def match_view_to_dash(content_results, explore_results, sql_table_name, proj):
         result['fields_used'] = content['query.formatted_fields']
 
         result['sql_table_name'] = sql_table_name_
-        result['lookml_file_name'] = sql_table_paths_
 
         for explore, tables in explore_results.items():
             if content['query.view'] == explore:
@@ -361,10 +381,7 @@ def match_view_to_dash(content_results, explore_results, sql_table_name, proj):
     return tables_in_explore
 
 
-# @snoop
 def main(**kwargs):
-    level = kwargs.get('level', 'INFO')
-    coloredlogs.install(level=level, logger=logger)
     cwd = Path.cwd()
     ini_file = kwargs.get("ini_file")
     config = ConfigParser.RawConfigParser(allow_no_value=True)
